@@ -2,12 +2,12 @@
 #######################################################################
 """The converterannotator class.
 
-$Id: converterannotator.py 49876 2008-02-02 14:18:55Z cray $
+$Id: converterannotator.py 49953 2008-02-06 20:22:05Z cray $
 """
 __author__  = "Ischenko Valera, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49876 $"
-__date__ = "$Date: 2008-02-02 17:18:55 +0300 (Сбт, 02 Фев 2008) $"
+__version__ = "$Revision: 49953 $"
+__date__ = "$Date: 2008-02-06 23:22:05 +0300 (Срд, 06 Фев 2008) $"
 __credits__ = """Andrey Orlov, for idea and common control"""
 
 from zope.interface import implements
@@ -92,11 +92,11 @@ class ConverterAnnotator(ConverterBase):
     def convert(self,text):
         """ Create annotation """
         text = super(ConverterAnnotator,self).convert(text)
-        self.sentences = re.findall(self.pattern_sentences, text)
+        sentences = re.findall(self.pattern_sentences, text)
         sentences_best = []
         number = 0
 
-        for sentence in self.sentences:
+        for sentence in sentences:
             words = re.findall(self.pattern_word, sentence)
             if self.normalisation == True:
                 words_norm = [word[:(  (len(word)>=self.minimal4norm) and int(len(word)*0.8) or len(word)  )].lower() for word in words]
@@ -118,7 +118,7 @@ class ConverterAnnotator(ConverterBase):
         
         result = ""
         for a in sentences_best:
-            result = result + " " + self.sentences[a._sentence]
+            result = result + " " + sentences[a._sentence]
 
         return result
 
